.. _core_device_configuration:

Configuration
-------------

Configure the General Settings to configure the device plugin.

:Device Auto Enrollment: Devices will be automatically enrolled without the
    intervention of an Administrator.

:Field Enrollment Enabled: Devices will enroll for the Field Service.

:Office Enrollemt Enabled: Devices will enroll for the Office Service.

:Offline Cache Refresh Seconds: This is the period of time a device will have
    its offline cache refreshed.

:Offline Master Switch Enabled: This allows an Administrator to enable or
    disable offline caching for all devices registered for caching.

:Slow Network Threshold: This is the network speed threshold for
    offline caching. When a device exceeds the threshold, offline caching
    is disabled on the device for 5 minutes.

.. image:: general_settings.png
    :align: center

